[tor-commits] [stem/master] Note that created descriptors aren't signed

atagar at torproject.org atagar at torproject.org
Tue May 2 19:57:29 UTC 2017


commit f655c68408924c87fc6dd170d0e108b8dd72a904
Author: Damian Johnson <atagar at torproject.org>
Date:   Mon May 1 11:56:53 2017 -0700

    Note that created descriptors aren't signed
    
    Love to have this capability but until we do we should note this.
---
 stem/descriptor/__init__.py | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)

diff --git a/stem/descriptor/__init__.py b/stem/descriptor/__init__.py
index c790e65..2b8ed5b 100644
--- a/stem/descriptor/__init__.py
+++ b/stem/descriptor/__init__.py
@@ -533,7 +533,8 @@ class Descriptor(object):
   def content(cls, attr = None, exclude = ()):
     """
     Creates descriptor content with the given attributes. Mandatory fields are
-    filled with dummy information unless data is supplied.
+    filled with dummy information unless data is supplied. This doesn't yet
+    create a valid signature.
 
     .. versionadded:: 1.6.0
 
@@ -552,7 +553,8 @@ class Descriptor(object):
   def create(cls, attr = None, exclude = (), validate = True):
     """
     Creates a descriptor with the given attributes. Mandatory fields are filled
-    with dummy information unless data is supplied.
+    with dummy information unless data is supplied. This doesn't yet create a
+    valid signature.
 
     .. versionadded:: 1.6.0
 





More information about the tor-commits mailing list